//
//  ViewController.m
//  ChartView

#import "ViewController.h"

@interface ViewController ()

@end

@implementation ViewController

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view.
    
    // Create Example data
    [self createExampleData];
    
    // Define DataSourceHelper specially for CategoryDateTimeXAxis
    source = [[IGCategoryDateSeriesDataSourceHelper alloc]init];
    source.data = _exampleDataArr;
    source.datePath = @"vsDate";
    source.valuePath = @"vsValue";
    
    // Define the ChartView
    IGChartView *infraChart = [[IGChartView alloc] initWithFrame:self.view.frame];
    infraChart.frame = CGRectMake(0, self.toolbar.frame.size.height, self.view.frame.size.width, self.view.frame.size.height - 2 * 96);
    [infraChart setAutoresizingMask:UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight];
    
    // Define Axis
    IGCategoryDateTimeXAxis *xAxis = [[IGCategoryDateTimeXAxis alloc] initWithKey:@"xAxis"];
    //IGCategoryXAxis *xAxis = [[IGCategoryXAxis alloc] initWithKey:@"xAxis"];
    IGNumericYAxis *yAxis = [[IGNumericYAxis alloc] initWithKey:@"yAxis"];
    [infraChart addAxis:xAxis];
    [infraChart addAxis:yAxis];
    
    // Define Area Series
    IGAreaSeries *areaSeries = [[IGAreaSeries alloc] initWithKey:@"areaSeries"];
    areaSeries.xAxis = xAxis;
    areaSeries.yAxis = yAxis;
    areaSeries.dataSource = source;
    //areaSeries.resolution = 2;
    [infraChart addSeries:areaSeries];
    
    infraChart.theme = [IGChartGradientThemes IGThemeDark];
    
    [self.view addSubview:infraChart];
    
    // ADD Zoombar
    IGChartView *zoomBarChart;
    IGRangeSelectorView *zoombar;
    
    // creates a new zoombar instance and sets it up beneath the chart.
    zoombar = [[IGRangeSelectorView alloc]initWithFrame:CGRectMake(0,
                                                                   self.view.frame.size.height - 2 * 100,
                                                                   self.view.frame.size.width, 2 * 100)];
    zoombar.autoresizingMask = UIViewAutoresizingFlexibleHeight|UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleTopMargin;
    [self.view addSubview:zoombar];
    
    // the igRangeSelector is tied to the chart's zoom display type.  Set the display type to the single axis
    // zoom we are trying to use.
    infraChart.zoomDisplayType = IGChartZoomHorizontal;
    infraChart.maximumZoomScale = 100;
    
    // ties the igRangeSelector to the chart.
    infraChart.zoombar = zoombar;
    
    
    // the igRangeSelector can show a view inside of itself to give an understanding of the data that will be zoomed.
    // In order to do this, a UIView should be set to the igRangeSelector's content view.
    
    // in this sample a second chart is being created and assigned to the igRangeSelector
    zoomBarChart = [[IGChartView alloc]init];
    IGLineSeries *lineSeries = (IGLineSeries*)[zoomBarChart addSeriesForType:[IGLineSeries class] usingKey:@"lineSeries" withDataSource:source firstAxisKey:@"xAxis" secondAxisKey:@"yAxis"];
    zoombar.contentView = zoomBarChart;
    lineSeries.xAxis.labelsVisible  = NO;
    lineSeries.yAxis.labelsVisible  = NO;
    zoombar.backgroundColor = [UIColor blackColor];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)createExampleData
{
    _exampleDataArr = [[NSMutableArray alloc] init];
    
    NSDateComponents *comps = [[NSDateComponents alloc] init];
    [comps setDay:01];
    [comps setMonth:01];
    [comps setYear:2013];
    [comps setHour:00];
    [comps setMinute:00];
    
    NSDate *date = [[NSCalendar currentCalendar] dateFromComponents:comps];
    
    for (int i = 0; i < 36000; i++)
    {
        ValueSeriesEntry *vsEntry = [[ValueSeriesEntry alloc] init];
        
        
        if(!i == 0)
        {
            date = [date dateByAddingTimeInterval:60*15];
        }
    
        vsEntry.vsDate = date;
        
        vsEntry.vsValue = arc4random() % 2000;
        
        [_exampleDataArr addObject:vsEntry];
    }
    
}


- (UIView *)chartView:(IGChartView *)chartView viewForTooltipWithItemlist:(NSDictionary *)itemlist
{
    UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"ChartTooltipUniversal.png"]];
    if ([itemlist count] > 0)
    {
        NSString *seriesKey = (NSString*)[[itemlist allKeys] objectAtIndex:0];
        double pointValue = ((IGCategoryPoint *)[itemlist valueForKey:seriesKey]).value;
        UILabel *valueLabel = [[UILabel alloc] init];
        valueLabel.backgroundColor = [UIColor clearColor];
        valueLabel.text = [NSString stringWithFormat:@"$%.2f\n", pointValue];
        [valueLabel sizeToFit];
        valueLabel.frame = CGRectMake(5, 5, valueLabel.frame.size.width, valueLabel.frame.size.height);
        [imageView addSubview:valueLabel];
    }
    return imageView;
}

@end
